@@ -134,6 +134,29 @@ Fl_Button *btn_yaesu_select_10 = (Fl_Button *)0;
 Fl_Button *btn_yaesu_select_11 = (Fl_Button *)0;
 Fl_ComboBox *op_yaesu_select60 = (Fl_ComboBox *)0;
 
+Fl_Group *tab_FT8n_bands = (Fl_Group *)0;
+Fl_Button *btn_FT8n_select_1 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_2 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_3 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_4 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_5 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_6 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_7 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_8 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_9 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_10 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_11 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_12 = (Fl_Button *)0;
+Fl_Button *btn_FT8n_select_13 = (Fl_Button *)0;
+
+Fl_Group *tab_FT8n_CTCSS = (Fl_Group *)0;
+Fl_PL_tone *choice_FT8n_tTONE = (Fl_PL_tone *)0;
+Fl_PL_tone *choice_FT8n_rTONE = (Fl_PL_tone *)0;
+Fl_Button *setTONES = (Fl_Button *)0;
+Fl_ComboBox *FMoffset = (Fl_ComboBox *)0;
+Fl_Button *setOFFSET = (Fl_Button *)0;
+cFreqControl *FMoff_freq = (cFreqControl *)0;
+
 Fl_Group *tab_icom_bands = (Fl_Group *)0;
 Fl_Button *btn_icom_select_1 = (Fl_Button *)0;
 Fl_Button *btn_icom_select_2 = (Fl_Button *)0;
@@ -216,7 +239,7 @@ Fl_Check_Button *btn_ext_tuner = (Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_on = (Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_off = (Fl_Check_Button *)0;
 
-Fl_Group  *genericUser = (Fl_Group *)0;
+Fl_Group  *genericUser_1 = (Fl_Group *)0;
 Fl_Button *btnUser1 = (Fl_Button*)0;
 Fl_Button *btnUser2 = (Fl_Button*)0;
 Fl_Button *btnUser3 = (Fl_Button*)0;
@@ -226,6 +249,16 @@ Fl_Button *btnUser6 = (Fl_Button*)0;
 Fl_Button *btnUser7 = (Fl_Button*)0;
 Fl_Button *btnUser8 = (Fl_Button*)0;
 
+Fl_Group  *genericUser_2 = (Fl_Group *)0;
+Fl_Button *btnUser9 = (Fl_Button*)0;
+Fl_Button *btnUser10 = (Fl_Button*)0;
+Fl_Button *btnUser11 = (Fl_Button*)0;
+Fl_Button *btnUser12 = (Fl_Button*)0;
+Fl_Button *btnUser13 = (Fl_Button*)0;
+Fl_Button *btnUser14 = (Fl_Button*)0;
+Fl_Button *btnUser15 = (Fl_Button*)0;
+Fl_Button *btnUser16 = (Fl_Button*)0;
+
 Fl_Group *genericRXB = (Fl_Group *)0;
 Hspinner *cntRIT = (Hspinner *)0;
 Hspinner *cntXIT = (Hspinner *)0;
@@ -362,6 +395,10 @@ static void cb_mnuTrace(Fl_Menu_*, void*) {
 	open_trace_tab();
 }
 
+static void cb_mnuCommands(Fl_Menu_ *, void *) {
+	open_commands_tab();
+}
+
 static void cb_Restore(Fl_Menu_*, void*) {
 	open_restore_tab();
 }
@@ -760,6 +797,14 @@ static void cb_btnUser( Fl_Button * o, void *d) {
 		case 6: cb_send_command(progStatus.command6, cmdResponse); break;
 		case 7: cb_send_command(progStatus.command7, cmdResponse); break;
 		case 8: cb_send_command(progStatus.command8, cmdResponse); break;
+		case 9: cb_send_command(progStatus.command9, cmdResponse); break;
+		case 10: cb_send_command(progStatus.command10, cmdResponse); break;
+		case 11: cb_send_command(progStatus.command11, cmdResponse); break;
+		case 12: cb_send_command(progStatus.command12, cmdResponse); break;
+		case 13: cb_send_command(progStatus.command13, cmdResponse); break;
+		case 14: cb_send_command(progStatus.command14, cmdResponse); break;
+		case 15: cb_send_command(progStatus.command15, cmdResponse); break;
+		case 16: cb_send_command(progStatus.command16, cmdResponse); break;
 	}
 }
 
@@ -1017,8 +1062,21 @@ int PL_tones[] = {
  948,  974, 1000, 1035, 1072, 1109, 1148, 1188, 1230, 1273,
 1318, 1365, 1413, 1462, 1514, 1567, 1598, 1622, 1655, 1679,
 1713, 1738, 1773, 1799, 1835, 1862, 1899, 1928, 1966, 1995,
-2035, 2065, 2107, 2181, 2257, 2291, 2336, 2418, 2503, 2540 };
+2035, 2065, 2107, 2181, 2257, 2291, 2336, 2418, 2503, 2541 };
 
+void cb_tones(Fl_Button *b, void *)
+{
+	int tTONE = PL_tones[choice_FT8n_tTONE->value()];
+	int rTONE = PL_tones[choice_FT8n_rTONE->value()];
+	guard_lock serial(&mutex_serial);
+	selrig->set_tones(tTONE, rTONE);
+}
+
+void cb_offset(Fl_Button *b, void*)
+{
+	guard_lock serial(&mutex_serial);
+	selrig->set_offset(FMoffset->index(), FMoff_freq->value());
+}
 
 #include "ui_small.cxx"
 
