@@ -32,6 +32,8 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Trace"), 0, (Fl_Callback*)cb_mnuTrace, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Restore"), 0, (Fl_Callback*)cb_Restore, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -48,7 +50,6 @@ Fl_Menu_Item menu_small_menu[] = {
  {_("&Help"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("On Line Help"), 0,  (Fl_Callback*)cb_mnuOnLineHelp, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&About"), 0,  (Fl_Callback*)cb_mnuAbout, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
- {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&Events"), 0,  (Fl_Callback*)cb_Events, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&xml-help"), 0,  (Fl_Callback*)cb_xml_help, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
@@ -112,7 +113,7 @@ Fl_Group *small_main_group(int X, int Y, int W, int H)
 	sldrVOLUME->textsize(12);
 	sldrVOLUME->callback((Fl_Callback*)cb_sldrVOLUME);
 	sldrVOLUME->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-	sldrVOLUME->when(FL_WHEN_CHANGED);
+	sldrVOLUME->when(FL_WHEN_CHANGED | FL_LEAVE);
 	sldrVOLUME->reverse(true);
 
 	btnAGC = new Fl_Light_Button(2, 145, 50, 18, _("AGC"));
@@ -1127,6 +1128,104 @@ Fl_Double_Window *tabs_window()
 
 		tab_yaesu_bands->end();
 
+		tab_FT8n_bands = new Fl_Group(0, 24, small_mainW, gph - 24, _("Bands"));
+		static const char setsave[] = _("Left click - set\nRight click - save");
+			btn_FT8n_select_1 = new Fl_Button(4, 30, 60, 18, _("1.8"));
+			btn_FT8n_select_1->tooltip(setsave);
+			btn_FT8n_select_1->color((Fl_Color)246);
+			btn_FT8n_select_1->callback((Fl_Callback*)cb_btn_band_select, (void *)1);
+
+			btn_FT8n_select_2 = new Fl_Button(74, 30, 60, 18, _("3.5"));
+			btn_FT8n_select_2->tooltip(setsave);
+			btn_FT8n_select_2->color((Fl_Color)246);
+			btn_FT8n_select_2->callback((Fl_Callback*)cb_btn_band_select, (void *)2);
+
+			btn_FT8n_select_3 = new Fl_Button(145, 30, 60, 18, _("7"));
+			btn_FT8n_select_3->tooltip(setsave);
+			btn_FT8n_select_3->color((Fl_Color)246);
+			btn_FT8n_select_3->callback((Fl_Callback*)cb_btn_band_select, (void *)3);
+
+			btn_FT8n_select_4 = new Fl_Button(216, 30, 60, 18, _("10"));
+			btn_FT8n_select_4->tooltip(setsave);
+			btn_FT8n_select_4->color((Fl_Color)246);
+			btn_FT8n_select_4->callback((Fl_Callback*)cb_btn_band_select, (void *)4);
+
+			btn_FT8n_select_5 = new Fl_Button(287, 30, 60, 18, _("14"));
+			btn_FT8n_select_5->tooltip(setsave);
+			btn_FT8n_select_5->color((Fl_Color)246);
+			btn_FT8n_select_5->callback((Fl_Callback*)cb_btn_band_select, (void *)5);
+
+			btn_FT8n_select_6 = new Fl_Button(358, 30, 60, 18, _("18"));
+			btn_FT8n_select_6->tooltip(setsave);
+			btn_FT8n_select_6->color((Fl_Color)246);
+			btn_FT8n_select_6->callback((Fl_Callback*)cb_btn_band_select, (void *)6);
+
+			btn_FT8n_select_7 = new Fl_Button(4, 50, 60, 18, _("21"));
+			btn_FT8n_select_7->tooltip(setsave);
+			btn_FT8n_select_7->color((Fl_Color)246);
+			btn_FT8n_select_7->callback((Fl_Callback*)cb_btn_band_select, (void *)7);
+
+			btn_FT8n_select_8 = new Fl_Button(74, 50, 60, 18, _("24"));
+			btn_FT8n_select_8->tooltip(setsave);
+			btn_FT8n_select_8->color((Fl_Color)246);
+			btn_FT8n_select_8->callback((Fl_Callback*)cb_btn_band_select, (void *)8);
+
+			btn_FT8n_select_9 = new Fl_Button(145, 50, 60, 18, _("28"));
+			btn_FT8n_select_9->tooltip(setsave);
+			btn_FT8n_select_9->color((Fl_Color)246);
+			btn_FT8n_select_9->callback((Fl_Callback*)cb_btn_band_select, (void *)9);
+
+			btn_FT8n_select_10 = new Fl_Button(216, 50, 60, 18, _("50"));
+			btn_FT8n_select_10->tooltip(setsave);
+			btn_FT8n_select_10->color((Fl_Color)246);
+			btn_FT8n_select_10->callback((Fl_Callback*)cb_btn_band_select, (void *)10);
+
+			btn_FT8n_select_11 = new Fl_Button(287, 50, 60, 18, _("144"));
+			btn_FT8n_select_11->tooltip(setsave);
+			btn_FT8n_select_11->color((Fl_Color)246);
+			btn_FT8n_select_11->callback((Fl_Callback*)cb_btn_band_select, (void *)11);
+
+			btn_FT8n_select_12 = new Fl_Button(358, 50, 60, 18, _("430"));
+			btn_FT8n_select_12->tooltip(setsave);
+			btn_FT8n_select_12->color((Fl_Color)246);
+			btn_FT8n_select_12->callback((Fl_Callback*)cb_btn_band_select, (void *)12);
+
+		tab_FT8n_bands->end();
+
+		tab_FT8n_CTCSS = new Fl_Group(0, 24, small_mainW, gph - 24, _("CTCSS"));
+
+			choice_FT8n_tTONE = new Fl_PL_tone(70, 34, 75, 18, _("Tone X:"));
+			choice_FT8n_tTONE->align((Fl_Align)FL_ALIGN_LEFT);
+			choice_FT8n_tTONE->value(8);
+			choice_FT8n_tTONE->end();
+
+			choice_FT8n_rTONE = new Fl_PL_tone(70, 66, 75, 18, _("R:"));
+			choice_FT8n_rTONE->align((Fl_Align)FL_ALIGN_LEFT);
+			choice_FT8n_rTONE->value(8);
+			choice_FT8n_rTONE->end();
+
+			setTONES = new Fl_Button(150, 34, 60, 18, _("Set"));
+			setTONES->callback((Fl_Callback*)cb_tones, 0);
+
+			FMoff_freq = new cFreqControl(225, 34, 100, 26, "5");
+			FMoff_freq->value(600);
+			Fl_Box *MHZ = new Fl_Box(FMoff_freq->x() + FMoff_freq->w() + 4, 34, 50, 26, "MHz");
+			MHZ->box(FL_FLAT_BOX);
+			MHZ->align(FL_ALIGN_CENTER);
+
+			FMoffset = new Fl_ComboBox(225, 66, 100, 18, "");
+			FMoffset->tooltip(_("Select FM operation"));
+			FMoffset->box(FL_NO_BOX);
+			FMoffset->color(FL_BACKGROUND2_COLOR);
+			FMoffset->selection_color(FL_BACKGROUND_COLOR);
+			FMoffset->add("simplex|minus|plus");
+			FMoffset->index(0);
+
+			setOFFSET = new Fl_Button(FMoffset->x() + FMoffset->w() + 5, 66, 60, 18, _("Set"));
+			setOFFSET->callback((Fl_Callback*)cb_offset, 0);
+
+		tab_FT8n_CTCSS->end();
+
 		tab_icom_bands = new Fl_Group(0, 24, small_mainW, gph - 24, _("Bands"));
 			btn_icom_select_1 = new Fl_Button(4, 30, 60, 18, _("1.8"));
 			btn_icom_select_1->tooltip(_("Left click - get\nRight click - set"));
@@ -1479,32 +1578,59 @@ Fl_Double_Window *tabs_window()
 
 		genericMisc->end();
 
-		genericUser = new Fl_Group(0, 24, small_mainW, gph - 24, _("User"));
-			btnUser1 = new Fl_Button(5, genericUser->y() + 12, 100, 20, "USER 1");
+		genericUser_1 = new Fl_Group(0, 24, small_mainW, gph - 24, _("User A"));
+			btnUser1 = new Fl_Button(5, genericUser_1->y() + 12, 100, 20, "USER 1");
 			btnUser1->callback((Fl_Callback*)cb_btnUser, (void*)1);
 
-			btnUser2 = new Fl_Button(110, genericUser->y() + 12, 100, 20, "USER 2");
+			btnUser2 = new Fl_Button(110, genericUser_1->y() + 12, 100, 20, "USER 2");
 			btnUser2->callback((Fl_Callback*)cb_btnUser, (void*)2);
 
-			btnUser3 = new Fl_Button(215, genericUser->y() + 12, 100, 20, "USER 3");
+			btnUser3 = new Fl_Button(215, genericUser_1->y() + 12, 100, 20, "USER 3");
 			btnUser3->callback((Fl_Callback*)cb_btnUser, (void*)3);
 
-			btnUser4 = new Fl_Button(320, genericUser->y() + 12, 100, 20, "USER 4");
+			btnUser4 = new Fl_Button(320, genericUser_1->y() + 12, 100, 20, "USER 4");
 			btnUser4->callback((Fl_Callback*)cb_btnUser, (void*)4);
 
-			btnUser5 = new Fl_Button(5, genericUser->y() + 36, 100, 20, "USER 5");
+			btnUser5 = new Fl_Button(5, genericUser_1->y() + 36, 100, 20, "USER 5");
 			btnUser5->callback((Fl_Callback*)cb_btnUser, (void*)5);
 
-			btnUser6 = new Fl_Button(110, genericUser->y() + 36, 100, 20, "USER 6");
+			btnUser6 = new Fl_Button(110, genericUser_1->y() + 36, 100, 20, "USER 6");
 			btnUser6->callback((Fl_Callback*)cb_btnUser, (void*)6);
 
-			btnUser7 = new Fl_Button(215, genericUser->y() + 36, 100, 20, "USER 7");
+			btnUser7 = new Fl_Button(215, genericUser_1->y() + 36, 100, 20, "USER 7");
 			btnUser7->callback((Fl_Callback*)cb_btnUser, (void*)7);
 
-			btnUser8 = new Fl_Button(320, genericUser->y() + 36, 100, 20, "USER 8");
+			btnUser8 = new Fl_Button(320, genericUser_1->y() + 36, 100, 20, "USER 8");
 			btnUser8->callback((Fl_Callback*)cb_btnUser, (void*)8);
 
-		genericUser->end();
+		genericUser_1->end();
+
+		genericUser_2 = new Fl_Group(0, 24, small_mainW, gph - 24, _("User B"));
+			btnUser9 = new Fl_Button(5, genericUser_2->y() + 12, 100, 20, "USER 9");
+			btnUser9->callback((Fl_Callback*)cb_btnUser, (void*)9);
+
+			btnUser10 = new Fl_Button(110, genericUser_2->y() + 12, 100, 20, "USER 10");
+			btnUser10->callback((Fl_Callback*)cb_btnUser, (void*)10);
+
+			btnUser11 = new Fl_Button(215, genericUser_2->y() + 12, 100, 20, "USER 11");
+			btnUser11->callback((Fl_Callback*)cb_btnUser, (void*)11);
+
+			btnUser12 = new Fl_Button(320, genericUser_2->y() + 12, 100, 20, "USER 12");
+			btnUser12->callback((Fl_Callback*)cb_btnUser, (void*)12);
+
+			btnUser13 = new Fl_Button(5, genericUser_2->y() + 36, 100, 20, "USER 13");
+			btnUser13->callback((Fl_Callback*)cb_btnUser, (void*)13);
+
+			btnUser14 = new Fl_Button(110, genericUser_2->y() + 36, 100, 20, "USER 14");
+			btnUser14->callback((Fl_Callback*)cb_btnUser, (void*)14);
+
+			btnUser15 = new Fl_Button(215, genericUser_2->y() + 36, 100, 20, "USER 15");
+			btnUser15->callback((Fl_Callback*)cb_btnUser, (void*)15);
+
+			btnUser16 = new Fl_Button(320, genericUser_2->y() + 36, 100, 20, "USER 16");
+			btnUser16->callback((Fl_Callback*)cb_btnUser, (void*)16);
+
+		genericUser_2->end();
 
 		tab7610 = new Fl_Group(0, 24, small_mainW, gph - 24, _("IC7610"));
 			ic7610att = new Fl_ComboBox(5, tab7610->y() + 10, 70, 20, "Att level");
@@ -1542,7 +1668,7 @@ Fl_Double_Window *tabs_window()
 
 		tab7610->end();
 
-	tabsGeneric->resizable(genericUser);
+	tabsGeneric->resizable(genericUser_2);
 	tabsGeneric->end();
 
 	grpTABS->end();
