@@ -41,6 +41,8 @@ Fl_Menu_Item touch_menu[] = {
  {_("AUX"), 0, (Fl_Callback*)cb_mnuAUX, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Polling"), 0, (Fl_Callback*)cb_Polling, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Trace"), 0, (Fl_Callback*)cb_mnuTrace, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Commands"), 0, (Fl_Callback*)cb_mnuCommands, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("Restore"), 0, (Fl_Callback*)cb_Restore, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("UI"), 0, 0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -56,7 +58,6 @@ Fl_Menu_Item touch_menu[] = {
  {_("&Help"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("On Line Help"), 0,  (Fl_Callback*)cb_mnuOnLineHelp, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&About"), 0,  (Fl_Callback*)cb_mnuAbout, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
- {_("Send command"), 0, (Fl_Callback*)cb_Send, 0, 128, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&Events"), 0,  (Fl_Callback*)cb_Events, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {_("&xml-help"), 0,  (Fl_Callback*)cb_xml_help, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
@@ -448,7 +449,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 			sldrVOLUME->textsize(14);
 			sldrVOLUME->callback((Fl_Callback*)cb_sldrVOLUME);
 			sldrVOLUME->align(Fl_Align(FL_ALIGN_CENTER|FL_ALIGN_INSIDE));
-			sldrVOLUME->when(FL_WHEN_CHANGED);
+			sldrVOLUME->when(FL_WHEN_CHANGED | FL_LEAVE);
 			Fl_Group::current()->resizable(sldrVOLUME);
 			sldrVOLUME->reverse(true);
 
@@ -888,6 +889,110 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			tab_yaesu_bands->end();
 
+			tab_FT8n_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Bands"));
+			static const char setsave[] = _("Left click - set\nRight click - save");
+				btn_FT8n_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
+				btn_FT8n_select_1->tooltip(setsave);
+				btn_FT8n_select_1->color((Fl_Color)246);
+				btn_FT8n_select_1->callback((Fl_Callback*)cb_btn_band_select, (void *)1);
+
+				btn_FT8n_select_2 = new Fl_Button(xpos+58, by, 50, bh, _("3.5"));
+				btn_FT8n_select_2->tooltip(setsave);
+				btn_FT8n_select_2->color((Fl_Color)246);
+				btn_FT8n_select_2->callback((Fl_Callback*)cb_btn_band_select, (void *)2);
+
+				btn_FT8n_select_3 = new Fl_Button(xpos+112, by, 50, bh, _("7"));
+				btn_FT8n_select_3->tooltip(setsave);
+				btn_FT8n_select_3->color((Fl_Color)246);
+				btn_FT8n_select_3->callback((Fl_Callback*)cb_btn_band_select, (void *)3);
+				btn_FT8n_select_3->align(Fl_Align(FL_ALIGN_CLIP));
+
+				btn_FT8n_select_4 = new Fl_Button(xpos+166, by, 50, bh, _("10"));
+				btn_FT8n_select_4->tooltip(setsave);
+				btn_FT8n_select_4->color((Fl_Color)246);
+				btn_FT8n_select_4->callback((Fl_Callback*)cb_btn_band_select, (void *)4);
+
+				btn_FT8n_select_5 = new Fl_Button(xpos+220, by, 50, bh, _("14"));
+				btn_FT8n_select_5->tooltip(setsave);
+				btn_FT8n_select_5->color((Fl_Color)246);
+				btn_FT8n_select_5->callback((Fl_Callback*)cb_btn_band_select, (void *)5);
+
+				btn_FT8n_select_6 = new Fl_Button(xpos+274, by, 50, bh, _("18"));
+				btn_FT8n_select_6->tooltip(setsave);
+				btn_FT8n_select_6->color((Fl_Color)246);
+				btn_FT8n_select_6->callback((Fl_Callback*)cb_btn_band_select, (void *)6);
+
+				btn_FT8n_select_7 = new Fl_Button(xpos+328, by, 50, bh, _("21"));
+				btn_FT8n_select_7->tooltip(setsave);
+				btn_FT8n_select_7->color((Fl_Color)246);
+				btn_FT8n_select_7->callback((Fl_Callback*)cb_btn_band_select, (void *)7);
+
+				btn_FT8n_select_8 = new Fl_Button(xpos+372, by, 50, bh, _("24"));
+				btn_FT8n_select_8->tooltip(setsave);
+				btn_FT8n_select_8->color((Fl_Color)246);
+				btn_FT8n_select_8->callback((Fl_Callback*)cb_btn_band_select, (void *)8);
+
+				btn_FT8n_select_9 = new Fl_Button(xpos+426, by, 50, bh, _("28"));
+				btn_FT8n_select_9->tooltip(setsave);
+				btn_FT8n_select_9->color((Fl_Color)246);
+				btn_FT8n_select_9->callback((Fl_Callback*)cb_btn_band_select, (void *)9);
+
+				btn_FT8n_select_10 = new Fl_Button(xpos+480, by, 50, bh, _("50"));
+				btn_FT8n_select_10->tooltip(setsave);
+				btn_FT8n_select_10->color((Fl_Color)246);
+				btn_FT8n_select_10->callback((Fl_Callback*)cb_btn_band_select, (void *)10);
+
+				btn_FT8n_select_11 = new Fl_Button(xpos+534, by, 50, bh, _("144"));
+				btn_FT8n_select_11->tooltip(setsave);
+				btn_FT8n_select_11->color((Fl_Color)246);
+				btn_FT8n_select_11->callback((Fl_Callback*)cb_btn_band_select, (void *)11);
+
+				btn_FT8n_select_12 = new Fl_Button(xpos+ 588, by, 50, bh, _("440"));
+				btn_FT8n_select_12->tooltip(setsave);
+				btn_FT8n_select_12->color((Fl_Color)246);
+				btn_FT8n_select_12->callback((Fl_Callback*)cb_btn_band_select, (void *)12);
+
+			tab_FT8n_bands->end();
+
+			tab_FT8n_CTCSS = new Fl_Group(xpos, ypos+tabh, W, tabb, _("CTCSS"));
+
+				choice_FT8n_tTONE = new Fl_PL_tone(xpos + 70, by+4, 75, 22, _("Tone X:"));
+				choice_FT8n_tTONE->align((Fl_Align)FL_ALIGN_LEFT);
+				choice_FT8n_tTONE->value(8);
+				choice_FT8n_tTONE->end();
+
+				choice_FT8n_rTONE = new Fl_PL_tone(
+					choice_FT8n_tTONE->x() + choice_FT8n_tTONE->w() + 30, by+4, 75, 22, _("R:"));
+				choice_FT8n_rTONE->align((Fl_Align)FL_ALIGN_LEFT);
+				choice_FT8n_rTONE->value(8);
+				choice_FT8n_rTONE->end();
+
+				setTONES = new Fl_Button(
+					choice_FT8n_rTONE->x() + choice_FT8n_rTONE->w() + 5, by+4, 80, 22, _("Set"));
+				setTONES->callback((Fl_Callback*)cb_tones, 0);
+
+				FMoffset = new Fl_ComboBox(
+					setTONES->x() + setTONES->w() + 5, by+4, 100, 22, "");
+				FMoffset->tooltip(_("Select FM operation"));
+				FMoffset->box(FL_NO_BOX);
+				FMoffset->color(FL_BACKGROUND2_COLOR);
+				FMoffset->selection_color(FL_BACKGROUND_COLOR);
+				FMoffset->add("simplex|minus|plus");
+				FMoffset->index(0);
+
+				FMoff_freq = new cFreqControl(FMoffset->x() + FMoffset->w() + 5, by+2, 100, 26, "5");
+				FMoff_freq->value(600);
+				Fl_Box *MHZ = new Fl_Box(FMoff_freq->x() + FMoff_freq->w() + 4, by+6, 40, 30, "MHz");
+				MHZ->box(FL_FLAT_BOX);
+				MHZ->align(FL_ALIGN_CENTER);
+				MHZ->labelsize(18);
+
+				setOFFSET = new Fl_Button(
+					MHZ->x() + MHZ->w() + 5, by+4, 80, 22, _("Set"));
+				setOFFSET->callback((Fl_Callback*)cb_offset, 0);
+
+			tab_FT8n_CTCSS->end();
+
 			tab_icom_bands = new Fl_Group(xpos, ypos+tabh, W, tabb, _("Bands"));
 
 				btn_icom_select_1 = new Fl_Button(xpos+4, by, 50, bh, _("1.8"));
@@ -1326,8 +1431,8 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 
 			genericAux->end();
 
-			genericUser = new Fl_Group(xpos, ypos+tabh, W, tabb, _("User"));
-				genericUser->hide();
+			genericUser_1 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("User A"));
+				genericUser_1->hide();
 
 				btnUser1 = new Fl_Button(5, by, 80, 50, "USER 1");
 				btnUser1->callback((Fl_Callback*)cb_btnUser, (void*)1);
@@ -1353,7 +1458,36 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 				btnUser8 = new Fl_Button(600, by, 80, 50, "USER 8");
 				btnUser8->callback((Fl_Callback*)cb_btnUser, (void*)8);
 
-			genericUser->end();
+			genericUser_1->end();
+
+			genericUser_2 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("User B"));
+				genericUser_2->hide();
+
+				btnUser9 = new Fl_Button(5, by, 80, 50, "USER 9");
+				btnUser9->callback((Fl_Callback*)cb_btnUser, (void*)9);
+
+				btnUser10 = new Fl_Button(90, by, 80, 50, "USER 10");
+				btnUser10->callback((Fl_Callback*)cb_btnUser, (void*)10);
+
+				btnUser11 = new Fl_Button(175, by, 80, 50, "USER 11");
+				btnUser11->callback((Fl_Callback*)cb_btnUser, (void*)11);
+
+				btnUser12 = new Fl_Button(260, by, 80, 50, "USER 12");
+				btnUser12->callback((Fl_Callback*)cb_btnUser, (void*)12);
+
+				btnUser13 = new Fl_Button(345, by, 80, 50, "USER 13");
+				btnUser13->callback((Fl_Callback*)cb_btnUser, (void*)13);
+
+				btnUser14 = new Fl_Button(430, by, 80, 50, "USER 14");
+				btnUser14->callback((Fl_Callback*)cb_btnUser, (void*)14);
+
+				btnUser15 = new Fl_Button(515, by, 80, 50, "USER 15");
+				btnUser15->callback((Fl_Callback*)cb_btnUser, (void*)15);
+
+				btnUser16 = new Fl_Button(600, by, 80, 50, "USER 16");
+				btnUser16->callback((Fl_Callback*)cb_btnUser, (void*)16);
+
+			genericUser_2->end();
 
 			tab7610 = new Fl_Group(xpos, ypos+tabh, W, tabb, _("IC7610"));
 				ic7610att = new Fl_ComboBox(5, by, 120, 50, "Att level");
