@@ -82,7 +82,8 @@ public:
 	int  get_volume_control();
 	void set_PTT_control(int val);
 	int  get_PTT();
-	void tune_rig();
+	void tune_rig(int);
+	int  get_tune();
 	int  next_attenuator();
 	void set_attenuator(int val);
 	int  get_attenuator();
