@@ -21,9 +21,9 @@
 #ifndef _TS480SAT_H
 #define _TS480SAT_H
 
-#include "rigbase.h"
+#include "KENWOOD.h"
 
-class RIG_TS480SAT : public rigbase {
+class RIG_TS480SAT : public KENWOOD {
 private:
 	bool beatcancel_on;
 	bool preamp_on;
@@ -36,17 +36,26 @@ public:
 	RIG_TS480SAT();
 	~RIG_TS480SAT(){}
 
-	bool sendTScommand(string, int);
-
 	void initialize();
 	void shutdown();
 
 	void check_menu_45();
 
-	long get_vfoA();
-	void set_vfoA(long);
-	long get_vfoB();
-	void set_vfoB(long);
+//	long get_vfoA();
+//	void set_vfoA(long);
+//	long get_vfoB();
+//	void set_vfoB(long);
+
+//	void selectA();
+//	void selectB();
+
+//	void set_split(bool val);
+//	bool can_split();
+//	int  get_split();
+//	bool twovfos() {return true;}
+
+	void set_PTT_control(int val);
+	int  get_PTT();
 
 	int  get_modetype(int n);
 	void set_modeA(int val);
@@ -58,25 +67,14 @@ public:
 	int  get_swr();
 	int  get_alc();
 	int  get_power_out();
-	void set_PTT_control(int val);
-	int  get_PTT();
-
-	void tune_rig();
+//	void tune_rig();
 
 	void set_bwA(int val);
 	int  get_bwA();
 	void set_bwB(int val);
 	int  get_bwB();
-	void selectA();
-	void selectB();
-
-	void set_split(bool val);
-	bool can_split();
-	int  get_split();
-	bool twovfos() {return true;}
-
-	void set_volume_control(int val);
-	int  get_volume_control();
+//	void set_volume_control(int val);
+//	int  get_volume_control();
 	void set_power_control(double val);
 	int  get_power_control();
 	void get_pc_min_max_step(double &min, double &max, double &step) {
@@ -89,13 +87,13 @@ public:
 	void set_noise(bool b);
 	int  get_noise();
 
-	void set_mic_gain(int val);
-	int  get_mic_gain();
-	void get_mic_min_max_step(int &min, int &max, int &step);
+//	void set_mic_gain(int val);
+//	int  get_mic_gain();
+//	void get_mic_min_max_step(int &min, int &max, int &step);
 
-	void set_squelch(int val);
-	int  get_squelch();
-	void get_squelch_min_max_step(int &min, int &max, int &step);
+//	void set_squelch(int val);
+//	int  get_squelch();
+//	void get_squelch_min_max_step(int &min, int &max, int &step);
 
 	void set_rf_gain(int val);
 	int  get_rf_gain();
@@ -130,6 +128,7 @@ public:
 	const char **hitable(int);
 
 	const char * get_bwname_(int bw, int md);
+
 };
 
 
