@@ -175,6 +175,29 @@ extern Fl_Button *btn_yaesu_select_10;
 extern Fl_Button *btn_yaesu_select_11;
 extern Fl_ComboBox *op_yaesu_select60;
 
+extern Fl_Group *tab_FT8n_bands;
+extern Fl_Button *btn_FT8n_select_1;
+extern Fl_Button *btn_FT8n_select_2;
+extern Fl_Button *btn_FT8n_select_3;
+extern Fl_Button *btn_FT8n_select_4;
+extern Fl_Button *btn_FT8n_select_5;
+extern Fl_Button *btn_FT8n_select_6;
+extern Fl_Button *btn_FT8n_select_7;
+extern Fl_Button *btn_FT8n_select_8;
+extern Fl_Button *btn_FT8n_select_9;
+extern Fl_Button *btn_FT8n_select_10;
+extern Fl_Button *btn_FT8n_select_11;
+extern Fl_Button *btn_FT8n_select_12;
+extern Fl_Button *btn_FT8n_select_13;
+
+extern Fl_Group *tab_FT8n_CTCSS;
+extern Fl_PL_tone *choice_FT8n_tTONE;
+extern Fl_PL_tone *choice_FT8n_rTONE;
+extern Fl_Button *setTONES;
+extern Fl_ComboBox *FMoffset;
+extern Fl_Button *setOFFSET;
+extern cFreqControl *FMoff_freq;
+
 extern Fl_Group *tab_icom_bands;
 extern Fl_Button *btn_icom_select_1;
 extern Fl_Button *btn_icom_select_2;
@@ -210,7 +233,7 @@ extern Fl_Light_Button *ic7610dual_watch;
 extern Fl_Light_Button *ic7610digi_sel_on_off;
 extern Fl_Wheel_Value_Slider *ic7610_digi_sel_val;
 
-extern Fl_Group  *genericUser;
+extern Fl_Group  *genericUser_1;
 extern Fl_Button *btnUser1;
 extern Fl_Button *btnUser2;
 extern Fl_Button *btnUser3;
@@ -219,7 +242,17 @@ extern Fl_Button *btnUser5;
 extern Fl_Button *btnUser6;
 extern Fl_Button *btnUser7;
 extern Fl_Button *btnUser8;
-extern Fl_Output * cmdResponse;
+extern Fl_Output *cmdResponse;
+
+extern Fl_Group  *genericUser_2;
+extern Fl_Button *btnUser9;
+extern Fl_Button *btnUser10;
+extern Fl_Button *btnUser11;
+extern Fl_Button *btnUser12;
+extern Fl_Button *btnUser13;
+extern Fl_Button *btnUser14;
+extern Fl_Button *btnUser15;
+extern Fl_Button *btnUser16;
 
 extern Hspinner *spnr_cw_spot_tone;
 extern Hspinner *spnr_cw_qsk;
@@ -371,7 +404,10 @@ extern Fl_Tabs *tabsConfig;
 extern Fl_Group *tabPrimary;
 extern Fl_ComboBox *selectRig;
 
-extern Fl_Group *tabCmds;
+extern Fl_Group *tabCommands;
+extern Fl_Tabs *tabCmds;
+extern Fl_Group *tabCmds1;
+extern Fl_Group *tabCmds2;
 extern Fl_Input2 * cmdlbl1;
 extern Fl_Input2 * cmdlbl2;
 extern Fl_Input2 * cmdlbl3;
@@ -380,6 +416,14 @@ extern Fl_Input2 * cmdlbl5;
 extern Fl_Input2 * cmdlbl6;
 extern Fl_Input2 * cmdlbl7;
 extern Fl_Input2 * cmdlbl8;
+extern Fl_Input2 * cmdlbl9;
+extern Fl_Input2 * cmdlbl10;
+extern Fl_Input2 * cmdlbl11;
+extern Fl_Input2 * cmdlbl12;
+extern Fl_Input2 * cmdlbl13;
+extern Fl_Input2 * cmdlbl14;
+extern Fl_Input2 * cmdlbl15;
+extern Fl_Input2 * cmdlbl16;
 extern Fl_Input2 * cmdtext1;
 extern Fl_Input2 * cmdtext2;
 extern Fl_Input2 * cmdtext3;
@@ -388,6 +432,14 @@ extern Fl_Input2 * cmdtext5;
 extern Fl_Input2 * cmdtext6;
 extern Fl_Input2 * cmdtext7;
 extern Fl_Input2 * cmdtext8;
+extern Fl_Input2 * cmdtext9;
+extern Fl_Input2 * cmdtext10;
+extern Fl_Input2 * cmdtext11;
+extern Fl_Input2 * cmdtext12;
+extern Fl_Input2 * cmdtext13;
+extern Fl_Input2 * cmdtext14;
+extern Fl_Input2 * cmdtext15;
+extern Fl_Input2 * cmdtext16;
 
 extern Fl_Counter *cntRigCatRetries;
 extern Fl_Counter *cntRigCatTimeout;
