@@ -22,17 +22,7 @@
 #ifndef TOD_H_
 #define TOD_H_
 
-extern unsigned long zmsec();
-extern char* zdate();
-extern char* ztime();
-extern char* zshowtime();
-
-//======================================================================
-// TOD Thread loop
-//======================================================================
-
-extern void *TOD_loop(void *args);
-extern void TOD_init();
-extern void TOD_close();
+extern int   zmsec();
+extern char *ztime();
 
 #endif // TOD_H_
