@@ -26,6 +26,7 @@
 #include <sstream>
 #include <cstring>
 #include <ctime>
+#include <exception>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdio.h>
@@ -41,6 +42,8 @@
 #include <FL/x.H>
 #include <FL/Fl_Help_Dialog.H>
 #include <FL/Fl_Menu_Item.H>
+#include <FL/Fl_Text_Display.H>
+#include <FL/Fl_Text_Buffer.H>
 
 #ifdef WIN32
 #  include "flrigrc.h"
@@ -75,14 +78,14 @@
 //#include "xml_io.h"
 #include "serial.h"
 #include "ui.h"
-
-#include "tod_clock.h"
+#include "icons.h"
 
 #include "flrig_icon.cxx"
 
 int parse_args(int argc, char **argv, int& idx);
 
-Fl_Double_Window *mainwindow;
+Fl_Double_Window *mainwindow = (Fl_Double_Window *)0;
+Fl_Double_Window *tabs_dialog = (Fl_Double_Window *)0;
 
 string HomeDir;
 string RigHomeDir;
@@ -90,21 +93,27 @@ string TempDir;
 string defFileName;
 string title;
 
-#ifdef IC_DEBUG
-string ICDEBUGfname;
-#endif
-
 pthread_t *serial_thread = 0;
 pthread_t *digi_thread = 0;
 
 pthread_mutex_t mutex_serial = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t mutex_xmlrpc = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t mutex_queA = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t mutex_queB = PTHREAD_MUTEX_INITIALIZER;
-pthread_mutex_t mutex_ptt = PTHREAD_MUTEX_INITIALIZER;
 
-bool RIG_DEBUG = false;
-bool XML_DEBUG = false;
+//pthread_mutex_t mutex_xmlrpc = PTHREAD_MUTEX_INITIALIZER;
+
+pthread_mutex_t mutex_vfoque = PTHREAD_MUTEX_INITIALIZER;
+
+//pthread_mutex_t mutex_vfoque = PTHREAD_MUTEX_INITIALIZER;
+//pthread_mutex_t mutex_vfoque = PTHREAD_MUTEX_INITIALIZER;
+
+pthread_mutex_t mutex_ptt = PTHREAD_MUTEX_INITIALIZER;
+pthread_mutex_t mutex_replystr = PTHREAD_MUTEX_INITIALIZER;
+
+pthread_mutex_t mutex_srvc_reqs = PTHREAD_MUTEX_INITIALIZER;
+
+pthread_mutex_t mutex_trace = PTHREAD_MUTEX_INITIALIZER;
+
+int use_trace = 0;
+
 bool EXPAND_CONTROLS = false;
 
 int xmlport = 12345;
@@ -170,13 +179,6 @@ void visit_URL(void* arg)
 
 extern void saveFreqList();
 
-void * flrig_terminate(void) {
-	std::cerr << "terminating" << std::endl;
-	fl_message("Closing flrig");
-	cbExit();
-	return 0;
-}
-
 void showEvents(void *)
 {
 	debug::show();
@@ -267,8 +269,9 @@ void close_controls(void*)
 			mainwindow->size_range(735, 150, 0, 150);
 			break;
 		case small_ui :
-			if (EXPAND_CONTROLS && selrig->has_extras)
-				Fl::add_timeout(1.0, expand_controls);
+			if (tabs_dialog && tabs_dialog->visible()) tabs_dialog->hide();
+//			if (EXPAND_CONTROLS && selrig->has_extras)
+//				Fl::add_timeout(1.0, expand_controls);
 			break;
 		case touch_ui :
 		default :
@@ -292,13 +295,14 @@ void startup(void*)
 			btn_show_controls->redraw_label();
 			grpTABS->hide();
 			mainwindow->resizable(grpTABS);
-			mainwindow->size(progStatus.mainW, 148);
-			mainwindow->size_range(735, 148, 0, 148);
+			mainwindow->size(progStatus.mainW, WIDE_MAINH);
+			mainwindow->size_range(735, WIDE_MAINH, 0, WIDE_MAINH);
 			mainwindow->redraw();
 		case small_ui :
 		default :
-			if (EXPAND_CONTROLS && selrig->has_extras)
-				show_controls();
+//			if (EXPAND_CONTROLS && selrig->has_extras)
+//				show_controls();
+				break;
 	}
 
 }
@@ -323,9 +327,15 @@ void rotate_log(std::string filename)
 	rename(filename.c_str(), oldfn.str().c_str());
 }
 
+void flrig_terminate() {
+	std::cerr << "terminating" << std::endl;
+	fl_message("Closing flrig");
+	cbExit();
+}
+
 int main (int argc, char *argv[])
 {
-	std::terminate_handler(flrig_terminate);
+	std::set_terminate(flrig_terminate);
 
 	int arg_idx;
 	HomeDir.clear();
@@ -393,11 +403,10 @@ extern FILE *serlog;
 		debug::start(fname.c_str());
 		time_t t = time(NULL);
 		LOG(debug::INFO_LEVEL, debug::LOG_OTHER, _("%s log started on %s"), PACKAGE_STRING, ctime(&t));
-#ifdef IC_DEBUG
-		ICDEBUGfname = RigHomeDir;
-		ICDEBUGfname.append("civ.txt");
-		rotate_log(ICDEBUGfname);
-#endif
+		string trace_fname = RigHomeDir;
+		trace_fname.append("trace.txt");
+		rotate_log(trace_fname);
+
 	}
 	catch (const char* error) {
 		cerr << error << '\n';
@@ -407,12 +416,16 @@ extern FILE *serlog;
 
 	progStatus.loadLastState();
 
+	if (use_trace) progStatus.trace = true;
+
 	switch (progStatus.UIsize) {
 		case touch_ui :
 			mainwindow = touch_rig_window();
 			break;
 		case small_ui :
 			mainwindow = Small_rig_window();
+			tabs_dialog = tabs_window();
+			tabs_dialog->hide();
 			break;
 		case wide_ui :
 		default :
@@ -439,17 +452,6 @@ extern FILE *serlog;
 		exit(EXIT_FAILURE);
 	}
 
-	TOD_init();
-
-//	if (progStatus.fldigi_is_server) {
-//		open_rig_xmlrpc();
-//		digi_thread = new pthread_t;      
-//		if (pthread_create(digi_thread, NULL, digi_loop, NULL)) {
-//			perror("pthread_create");
-//			exit(EXIT_FAILURE);
-//		}
-//	} else
-
 	start_server(xmlport);
 
 	createXcvrDialog();
@@ -509,32 +511,68 @@ extern FILE *serlog;
 
 }
 
+void cl_print(std::string cl)
+{
+	Fl_Double_Window clwin(50,50,600,500, "Command line text");
+		Fl_Text_Display cldisplay(2,2,596,496);
+		Fl_Text_Buffer  clbuff;
+
+		cldisplay.buffer(&clbuff);
+		cldisplay.textfont(FL_COURIER);
+
+		cldisplay.insert(cl.c_str());
+
+	clwin.end();
+	clwin.resizable(cldisplay);
+
+	clwin.show();
+
+	while (clwin.visible()) {
+		Fl::wait();
+		MilliSleep(50);
+	}
+}
+
+void cb_xml_help(Fl_Menu_*, void*)
+{
+	cl_print(print_xmlhelp());
+}
+
 int parse_args(int argc, char **argv, int& idx)
 {
-	if (strcasecmp("--help", argv[idx]) == 0) {
-		printf("Usage: \n\
+	std::string helpstr =
+"Usage: \n\
   --help this help text\n\
   --version\n\
-  --config-dir <DIR>\n\
+  --config-dir [fully qualified pathname to <DIR>]\n\
   --debug-level N (0..4)\n\
-  --rig_debug\n\
-  --xml_debug\n\
-  --exp (expand menu tab controls)\n\n");
+  --trace\n\
+  --xml-help\n\
+  --xml-trace\n\
+  --exp (expand menu tab controls)";
+
+	if (strcasecmp("--help", argv[idx]) == 0) {
+#ifdef __WIN32__
+		fl_alert2("%s", helpstr.c_str());
+#else
+		std::cout << helpstr << std::endl;
+#endif
 		exit(0);
 	} 
 	if (strcasecmp("--version", argv[idx]) == 0) {
-		printf("Version: "VERSION"\n");
+		std::string ver = "Version: ";
+		ver.append(VERSION).append("\n");
+		std::cout << ver;
 		exit (0);
 	}
-	if (strcasecmp("--rig_debug", argv[idx]) == 0) {
-		RIG_DEBUG = true;
+	if (strcasecmp("--trace", argv[idx]) == 0) {
+		use_trace = true;
 		idx++;
 		return 1;
 	}
-	if (strcasecmp("--xml_debug", argv[idx]) == 0) {
-		XML_DEBUG = true;
-		idx++;
-		return 1;
+	if (strcasecmp("--xml-help", argv[idx]) == 0) {
+		std::cout << print_xmlhelp();
+		exit(0);
 	}
 	if (strcasecmp("--debug-level", argv[idx]) == 0) {
 		string level = argv[idx + 1];
@@ -561,5 +599,14 @@ int parse_args(int argc, char **argv, int& idx)
 		idx++;
 		return 1;
 	}
+#  ifdef __APPLE__
+	if (strncasecmp("-psn", argv[idx], 4) == 0) {
+		idx++;
+		return 1;
+	}
+#endif
+	fl_alert2("Unknown command line parameter: \"%s\"\n\n%s", argv[idx], helpstr.c_str());
+	exit(0);
+
 	return 0;
 }
