@@ -291,25 +291,17 @@ int RIG_FT450::get_split()
 {
 	size_t p;
 	int split = 0;
-	char rx, tx;
+	char tx;
 // tx vfo
 	cmd = rsp = "FT";
 	cmd.append(";");
-	waitN(4, 100, "get split tx vfo", ASC);
+	wait_char(';',4, 100, "get split tx vfo", ASC);
+
 	p = replystr.rfind(rsp);
 	if (p == string::npos) return false;
 	tx = replystr[p+2] - '0';
 
-// rx vfo
-	cmd = rsp = "FR";
-	cmd.append(";");
-	waitN(4, 100, "get split rx vfo", ASC);
-
-	p = replystr.rfind(rsp);
-	if (p == string::npos) return false;
-	rx = replystr[p+2] - '0';
-
-	split = (tx == 1 ? 2 : 0) + (rx >= 4 ? 1 : 0);
+	split = (tx == 1 ? 2 : 0);
 
 	return split;
 }
@@ -455,11 +447,37 @@ int RIG_FT450::get_PTT()
 	return ptt_;
 }
 
-void RIG_FT450::tune_rig()
+void RIG_FT450::tune_rig(int val)
 {
-	cmd = "AC002;";
+	switch (val) {
+		case 0:
+			cmd = "AC000;";
+			break;
+		case 1:
+			cmd = "AC001;";
+			break;
+		case 2:
+		default:
+			cmd = "AC002;";
+			break;
+	}
 	sendCommand(cmd);
 	showresp(WARN, ASC, "tune rig", cmd, replystr);
+	sett("tune_rig");
+}
+
+int RIG_FT450::get_tune()
+{
+	cmd = rsp = "AC";
+	cmd += ';';
+	waitN(5, 100, "get tune", ASC);
+
+	rig_trace(2, "get_tuner status()", replystr.c_str());
+
+	size_t p = replystr.rfind(rsp);
+	if (p == string::npos) return 0;
+	int val = replystr[p+4] - '0';
+	return (val > 0);
 }
 
 void RIG_FT450::set_attenuator(int val)
@@ -480,7 +498,7 @@ int RIG_FT450::get_attenuator()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return 0;
-	return (replystr[p+3] == '1' ? 1 : 0);
+	return (replystr[p+3] == '3' ? 1 : 0);
 }
 
 void RIG_FT450::set_preamp(int val)
@@ -501,7 +519,7 @@ int RIG_FT450::get_preamp()
 
 	size_t p = replystr.rfind(rsp);
 	if (p == string::npos) return 0;
-	return (replystr[p+3] == '1' ? 0 : 1);
+	return (replystr[p+3] == '1' ? 1 : 0);
 }
 
 const char ** RIG_FT450::bwtable(int n)
@@ -840,25 +858,20 @@ void RIG_FT450::set_noise(bool b)
 
 void RIG_FT450::set_xcvr_auto_on()
 {
-	if (!progStatus.xcvr_auto_on) return;
-
-	cmd = rsp = "PS";
-	cmd.append(";");
-	waitN(4, 100, "Test: Is Rig ON", ASC);
-	size_t p = replystr.rfind(rsp);
-	if (p == string::npos) {	// rig is off, power on
-		cmd = "PS1;";
-		sendCommand(cmd);
-		MilliSleep(1500);	// 1.0 < T < 2.0 seconds
-		sendCommand(cmd);
-		MilliSleep(3000);	// Wait for rig startup?  Maybe not needed.
-	}
+// send dummy data request for ID (see pg 12 CAT reference book)
+	cmd = "ID;";
+	sendCommand(cmd);
+// wait 1 to 2 seconds
+	MilliSleep(1500);
+	cmd = "PS1;";
+	sendCommand(cmd);
+// wait for power on status
+	cmd = "PS;";
+	waitN(4, 500, "Xcvr ON?", ASC);
 }
 
 void RIG_FT450::set_xcvr_auto_off()
 {
-	if (!progStatus.xcvr_auto_off) return;
-
 	cmd = "PS0;";
 	sendCommand(cmd);
 }
