@@ -77,20 +77,65 @@ const char *IC7000_FMwidths[] = { "FIXED", NULL };
 static int IC7000_bw_vals_FM[] = {
 1, WVALS_LIMIT};
 
-static GUI rig_widgets[]= {
-	{ (Fl_Widget *)btnVol,        2, 125,  50 },
-	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },
-	{ (Fl_Widget *)sldrRFGAIN,  266, 125, 156 },
-	{ (Fl_Widget *)sldrMICGAIN, 266, 145, 156 },
-	{ (Fl_Widget *)sldrSQUELCH, 266, 105, 156 },
-	{ (Fl_Widget *)btnNR,         2, 145,  50 },
-	{ (Fl_Widget *)sldrNR,       54, 145, 156 },
-	{ (Fl_Widget *)btnNotch,      2, 165,  50 },
-	{ (Fl_Widget *)sldrNOTCH,    54, 165, 156 },
-	{ (Fl_Widget *)sldrPOWER,   266, 165, 156 },
+static GUI IC7000_widgets[]= {
+	{ (Fl_Widget *)btnVol,        2, 125,  50 },	//0
+	{ (Fl_Widget *)sldrVOLUME,   54, 125, 156 },	//1
+	{ (Fl_Widget *)btnAGC,        2, 145,  50 },	//2
+	{ (Fl_Widget *)sldrRFGAIN,   54, 145, 156 },	//3
+	{ (Fl_Widget *)sldrSQUELCH,  54, 165, 156 },	//4
+	{ (Fl_Widget *)btnNR,         2, 185,  50 },	//5
+	{ (Fl_Widget *)sldrNR,       54, 185, 156 },	//6
+	{ (Fl_Widget *)btnLOCK,     214, 105,  50 },	//7
+	{ (Fl_Widget *)sldrINNER,   266, 105, 156 },	//8
+	{ (Fl_Widget *)btnCLRPBT,   214, 125,  50 },	//9
+	{ (Fl_Widget *)sldrOUTER,   266, 125, 156 },	//10
+	{ (Fl_Widget *)btnNotch,    214, 145,  50 },	//11
+	{ (Fl_Widget *)sldrNOTCH,   266, 145, 156 },	//12
+	{ (Fl_Widget *)sldrMICGAIN, 266, 165, 156 },	//13
+	{ (Fl_Widget *)sldrPOWER,   266, 185, 156 },	//14
 	{ (Fl_Widget *)NULL, 0, 0, 0 }
 };
 
+void RIG_IC7000::initialize()
+{
+	IC7000_widgets[0].W = btnVol;
+	IC7000_widgets[1].W = sldrVOLUME;
+	IC7000_widgets[2].W = btnAGC;
+	IC7000_widgets[3].W = sldrRFGAIN;
+	IC7000_widgets[4].W = sldrSQUELCH;
+	IC7000_widgets[5].W = btnNR;
+	IC7000_widgets[6].W = sldrNR;
+	IC7000_widgets[7].W = btnLOCK;
+	IC7000_widgets[8].W = sldrINNER;
+	IC7000_widgets[9].W = btnCLRPBT;
+	IC7000_widgets[10].W = sldrOUTER;
+	IC7000_widgets[11].W = btnNotch;
+	IC7000_widgets[12].W = sldrNOTCH;
+	IC7000_widgets[13].W = sldrMICGAIN;
+	IC7000_widgets[14].W = sldrPOWER;
+
+	btn_icom_select_11->activate();
+	btn_icom_select_12->activate();
+	btn_icom_select_13->deactivate();
+
+	cmd = pre_to;
+	cmd += '\x1A';
+	cmd += '\x05';
+	cmd += '\x00';
+	cmd += '\x92';
+	cmd += '\x00';
+	cmd.append(post);
+	if (!waitFB("CI-V") && RigSerial->IsOpen()) {
+		flrig_abort = true;
+		return;
+	}
+	cmd = pre_to;
+	cmd.append("\x16\x51");
+	cmd += '\x00';
+	cmd.append(post);
+	if (!waitFB("NF2 OFF") && RigSerial->IsOpen()) flrig_abort = true;
+}
+
 RIG_IC7000::RIG_IC7000() {
 	defaultCIV = 0x70;
 	name_ = IC7000name_;
@@ -99,11 +144,11 @@ RIG_IC7000::RIG_IC7000() {
 	bw_vals_ = IC7000_bw_vals_SSB;
 
 	_mode_type = IC7000_mode_type;
-	widgets = rig_widgets;
+	widgets = IC7000_widgets;
 
-	A.freq = 432399230;
-	A.imode = 1;
-	A.iBW = 28;
+	def_freq = A.freq = 432399230;
+	def_mode = A.imode = 1;
+	def_bw = A.iBW = 28;
 	B.freq = 432399230;
 	B.imode = 1;
 	B.iBW = 28;
@@ -139,6 +184,8 @@ RIG_IC7000::RIG_IC7000() {
 	has_rf_control = 
 	has_sql_control = true;
 
+	has_band_selection = true;
+
 	precision = 1;
 	ndigits = 9;
 
@@ -150,37 +197,6 @@ RIG_IC7000::RIG_IC7000() {
 
 #include "debug.h"
 
-void RIG_IC7000::initialize()
-{
-	rig_widgets[0].W = btnVol;
-	rig_widgets[1].W = sldrVOLUME;
-	rig_widgets[2].W = sldrRFGAIN;
-	rig_widgets[3].W = sldrMICGAIN;
-	rig_widgets[4].W = sldrSQUELCH;
-	rig_widgets[5].W = btnNR;
-	rig_widgets[6].W = sldrNR;
-	rig_widgets[7].W = btnNotch;
-	rig_widgets[8].W = sldrNOTCH;
-	rig_widgets[9].W = sldrPOWER;
-
-	cmd = pre_to;
-	cmd += '\x1A';
-	cmd += '\x05';
-	cmd += '\x00';
-	cmd += '\x92';
-	cmd += '\x00';
-	cmd.append(post);
-	if (!waitFB("CI-V") && RigSerial->IsOpen()) {
-		flrig_abort = true;
-		return;
-	}
-	cmd = pre_to;
-	cmd.append("\x16\x51");
-	cmd += '\x00';
-	cmd.append(post);
-	if (!waitFB("NF2 OFF") && RigSerial->IsOpen()) flrig_abort = true;
-}
-
 void RIG_IC7000::selectA()
 {
 	cmd = pre_to;
@@ -199,8 +215,21 @@ void RIG_IC7000::selectB()
 	if (!waitFB("sel B") && RigSerial->IsOpen()) flrig_abort = true;
 }
 
+bool RIG_IC7000::check ()
+{
+	string resp = pre_fm;
+	resp += '\x03';
+	cmd = pre_to;
+	cmd += '\x03';
+	cmd.append( post );
+	bool ok = waitFOR(11, "check vfo");
+	rig_trace(2, "check()", str2hex(replystr.c_str(), replystr.length()));
+	return ok;
+}
+
 long RIG_IC7000::get_vfoA ()
 {
+	if (useB) return A.freq;
 	string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
@@ -227,6 +256,7 @@ void RIG_IC7000::set_vfoA (long freq)
 
 long RIG_IC7000::get_vfoB ()
 {
+	if (!useB) return B.freq;
 	string resp = pre_fm;
 	resp += '\x03';
 	cmd = pre_to;
@@ -900,3 +930,150 @@ int RIG_IC7000::get_PTT()
 	return ptt_;
 }
 
+void RIG_IC7000::set_pbt_inner(int val)
+{
+	int shift = 128 + val * 128 / 50;
+	if (shift < 0) shift = 0;
+	if (shift > 255) shift = 255;
+
+	cmd = pre_to;
+	cmd.append("\x14\x07");
+	cmd.append(to_bcd(shift, 3));
+	cmd.append(post);
+	waitFB("set PBT inner");
+}
+
+void RIG_IC7000::set_pbt_outer(int val)
+{
+	int shift = 128 + val * 128 / 50;
+	if (shift < 0) shift = 0;
+	if (shift > 255) shift = 255;
+
+	cmd = pre_to;
+	cmd.append("\x14\x08");
+	cmd.append(to_bcd(shift, 3));
+	cmd.append(post);
+	waitFB("set PBT outer");
+}
+
+int RIG_IC7000::get_pbt_inner()
+{
+	int val = 0;
+	string cstr = "\x14\x07";
+	string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append( post );
+	if (waitFOR(9, "get pbt inner")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos) {
+			val = num100(replystr.substr(p+6));
+			val -= 50;
+		}
+	}
+	rig_trace(2, "get_pbt_inner()", str2hex(replystr.c_str(), replystr.length()));
+	return val;
+}
+
+int RIG_IC7000::get_pbt_outer()
+{
+	int val = 0;
+	string cstr = "\x14\x08";
+	string resp = pre_fm;
+	resp.append(cstr);
+	cmd = pre_to;
+	cmd.append(cstr);
+	cmd.append( post );
+	if (waitFOR(9, "get pbt inner")) {
+		size_t p = replystr.rfind(resp);
+		if (p != string::npos) {
+			val = num100(replystr.substr(p+6));
+			val -= 50;
+		}
+	}
+	rig_trace(2, "get_pbt_outer()", str2hex(replystr.c_str(), replystr.length()));
+	return val;
+}
+
+// Read/Write band stack registers
+//
+// Read 23 bytes
+//
+//  0  1  2  3  4  5  6  7  8  9 10 11 12 13 14 15 16 17 18 19 20 21 22
+// FE FE nn E0 1A 01 bd rn f5 f4 f3 f2 f1 mo fi fg t1 t2 t3 r1 r2 r3 FD
+// Write 23 bytes
+//
+// FE FE E0 nn 1A 01 bd rn f5 f4 f3 f2 f1 mo fi fg t1 t2 t3 r1 r2 r3 FD
+//
+// nn - CI-V address
+// bd - band selection 1/2/3
+// rn - register number 1/2/3
+// f5..f1 - frequency BCD reverse
+// mo - mode
+// fi - filter #
+// fg flags: x01 use Tx tone, x02 use Rx tone, x10 data mode
+// t1..t3 - tx tone BCD fwd
+// r1..r3 - rx tone BCD fwd
+//
+// FE FE E0 94 1A 01 06 01 70 99 08 18 00 01 03 10 00 08 85 00 08 85 FD
+//
+// band 6; freq 0018,089,970; USB; data mode; t 88.5; r 88.5
+
+void RIG_IC7000::get_band_selection(int v)
+{
+	cmd.assign(pre_to);
+	cmd.append("\x1A\x01");
+	cmd += to_bcd_be( v, 2 );
+	cmd += '\x01';
+	cmd.append( post );
+	if (waitFOR(23, "get band stack")) {
+		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
+		size_t p = replystr.rfind(pre_fm);
+		if (p != string::npos) {
+			long int bandfreq = fm_bcd_be(replystr.substr(p+8, 5), 10);
+			int bandmode = replystr[p+13];
+			int bandfilter = replystr[p+14];
+			if (useB) {
+				set_vfoB(bandfreq);
+				set_modeB(bandmode);
+				set_FILT(bandfilter);
+			} else {
+				set_vfoA(bandfreq);
+				set_modeA(bandmode);
+				set_FILT(bandfilter);
+			}
+		}
+	} else
+		set_trace(2, "get band stack", str2hex(replystr.c_str(), replystr.length()));
+}
+
+void RIG_IC7000::set_band_selection(int v)
+{
+	long freq = (useB ? B.freq : A.freq);
+	int fil = (useB ? filB : filA);
+	int mode = (useB ? B.imode : A.imode);
+
+	cmd.assign(pre_to);
+	cmd.append("\x1A\x01");
+	cmd += to_bcd_be( v, 2 );
+	cmd += '\x01';
+	cmd.append( to_bcd_be( freq, 10 ) );
+	cmd += mode;
+	cmd += fil;
+	cmd += '\x00';
+	cmd.append(to_bcd(PL_tones[tTONE], 6));
+	cmd.append(to_bcd(PL_tones[rTONE], 6));
+	cmd.append(post);
+	waitFB("set_band_selection");
+	set_trace(2, "set_band_selection()", str2hex(replystr.c_str(), replystr.length()));
+
+	cmd.assign(pre_to);
+	cmd.append("\x1A\x01");
+	cmd += to_bcd_be( v, 2 );
+	cmd += '\x01';
+	cmd.append( post );
+
+	waitFOR(23, "get band stack");
+}
+
