@@ -74,8 +74,21 @@ void RIG_IC735::selectB()
 	waitFB("select B");
 }
 
+bool RIG_IC735::check ()
+{
+	string resp = pre_fm;
+	resp += '\x03';
+	cmd = pre_to;
+	cmd += '\x03';
+	cmd.append( post );
+	bool ok = waitFOR(10, "check vfo");
+	rig_trace(2, "check()", str2hex(replystr.c_str(), replystr.length()));
+	return ok;
+}
+
 long RIG_IC735::get_vfoA ()
 {
+	if (useB) return A.freq;
 	string cstr = "\x03";
 	string resp = pre_fm;
 	resp.append(cstr);
@@ -102,6 +115,7 @@ void RIG_IC735::set_vfoA (long freq)
 
 long RIG_IC735::get_vfoB ()
 {
+	if (!useB) return B.freq;
 	string cstr = "\x03";
 	string resp = pre_fm;
 	resp.append(cstr);
