@@ -693,19 +693,6 @@ void RIG_IC756PRO3::set_split(bool val)
 
 int RIG_IC756PRO3::get_split()
 {
-	int read_split = 0;
-	cmd.assign(pre_to);
-	cmd.append("\x0F");
-	cmd.append( post );
-	if (waitFOR(7, "get split")) {
-		string resp = pre_fm;
-		resp.append("\x0F");
-		size_t p = replystr.find(resp);
-		if (p != string::npos)
-			read_split = replystr[p+5];
-		if (read_split != 0xFA) // fail byte
-			split = read_split;
-	}
 	return split;
 }
 
