@@ -281,6 +281,24 @@ status progStatus = {
 	"",				// string	command7;
 	"cmd 8",		// string	label8;
 	"",				// string	command8;
+
+	"cmd 9",		// string	label9;
+	"",				// string	command9;
+	"cmd 10",		// string	label10;
+	"",				// string	command10;
+	"cmd 11",		// string	label11;
+	"",				// string	command11;
+	"cmd 12",		// string	label12;
+	"",				// string	command12;
+	"cmd 13",		// string	label13;
+	"",				// string	command13;
+	"cmd 14",		// string	label14;
+	"",				// string	command14;
+	"cmd 15",		// string	label15;
+	"",				// string	command15;
+	"cmd 16",		// string	label16;
+	"",				// string	command16;
+
 // =========================
 	232,		// int	 bg_red;
 	255,		// int	 bg_green;
@@ -360,7 +378,22 @@ status progStatus = {
 	false,		// bool	xmltrace;
 	false,		// bool	rpctrace;
 	false,		// bool	start_stop_trace;
-	0			// int	rpc_level;
+	0,			// int	rpc_level;
+
+// bands; defaults for FT857 / FT897
+// frequency, mode, txCTCSS, rxCTCSS, offset, offset_freq;
+	1805000L, 6, 0, 0, 0, 600, 		// f160
+	3580000L, 6, 0, 0, 0, 600,		// f80 meters
+	7070000L, 6, 0, 0, 0, 600,		// f40 meters
+	10140000L, 6, 0, 0, 0, 600,		// f30 meters
+	14070000L, 6, 0, 0, 0, 600,		// f20 meters
+	18100000L, 6, 0, 0, 0, 600,		// f17 meters
+	21070000L, 6, 0, 0, 0, 600,		// f15 meters
+	24920000L, 6, 0, 0, 0, 600,		// f12 meters
+	28070000L, 6, 0, 0, 0, 600,		// f10 meters
+	50070000L, 6, 0, 0, 0, 600,		// f6 meters
+	144070000L, 6, 0, 0, 0, 600,	// f2 meters
+	432100000L, 6, 0, 0, 0, 600		// f70 cent'
 };
 
 void status::saveLastState()
@@ -621,6 +654,23 @@ void status::saveLastState()
 	spref.set("label8", label8.c_str());
 	spref.set("command8", command8.c_str());
 
+	spref.set("label9", label9.c_str());
+	spref.set("command9", command9.c_str());
+	spref.set("label10", label10.c_str());
+	spref.set("command10", command10.c_str());
+	spref.set("label11", label11.c_str());
+	spref.set("command11", command11.c_str());
+	spref.set("label12", label12.c_str());
+	spref.set("command12", command12.c_str());
+	spref.set("label13", label13.c_str());
+	spref.set("command13", command13.c_str());
+	spref.set("label14", label14.c_str());
+	spref.set("command14", command14.c_str());
+	spref.set("label15", label15.c_str());
+	spref.set("command15", command15.c_str());
+	spref.set("label16", label16.c_str());
+	spref.set("command16", command16.c_str());
+
 	spref.set("fg_red", fg_red);
 	spref.set("fg_green", fg_green);
 	spref.set("fg_blue", fg_blue);
@@ -700,6 +750,43 @@ void status::saveLastState()
 	spref.set("startstoptrace", start_stop_trace);
 	spref.set("rpc_level", rpc_level);
 
+	spref.set("f160", f160); spref.set("m160", m160);
+	spref.set("txT160", txT_160); spref.set("rxT160", rxT_160);
+	spref.set("offset_160", offset_160); spref.set("oF_160", oF_160);
+	spref.set("f80", f80);   spref.set("m80", m80);
+	spref.set("txT80", txT_80); spref.set("rxT80", rxT_80);
+	spref.set("offset_80", offset_80); spref.set("oF_80", oF_80);
+	spref.set("f40", f40);   spref.set("m40", m40);
+	spref.set("txT40", txT_40); spref.set("rxT40", rxT_40);
+	spref.set("offset_40", offset_40); spref.set("oF_40", oF_40);
+	spref.set("f30", f30);   spref.set("m30", m30);
+	spref.set("txT30", txT_30); spref.set("rxT30", rxT_30);
+	spref.set("offset_30", offset_30); spref.set("oF_30", oF_30);
+	spref.set("f20", f20);   spref.set("m20", m20);
+	spref.set("txT20", txT_20); spref.set("rxT20", rxT_20);
+	spref.set("offset_20", offset_20); spref.set("oF_20", oF_20);
+	spref.set("f17", f17);   spref.set("m17", m17);
+	spref.set("txT17", txT_17); spref.set("rxT17", rxT_17);
+	spref.set("offset_17", offset_17); spref.set("oF_17", oF_17);
+	spref.set("f15", f15);   spref.set("m15", m15);
+	spref.set("txT15", txT_15); spref.set("rxT15", rxT_15);
+	spref.set("offset_15", offset_15); spref.set("oF_15", oF_15);
+	spref.set("f12", f12);   spref.set("m12", m12);
+	spref.set("txT12", txT_12); spref.set("rxT12", rxT_12);
+	spref.set("offset_12", offset_12); spref.set("oF_12", oF_12);
+	spref.set("f10", f10);   spref.set("m10", m10);
+	spref.set("txT10", txT_10); spref.set("rxT10", rxT_10);
+	spref.set("offset_10", offset_10); spref.set("oF_10", oF_10);
+	spref.set("f6", f6);     spref.set("m6", m6);
+	spref.set("txT6", txT_6); spref.set("rxT_6", rxT_6);
+	spref.set("offset_6", offset_6); spref.set("oF_6", oF_6);
+	spref.set("f2", f2);     spref.set("m2", m2);
+	spref.set("txT2", txT_2); spref.set("rxT2", rxT_2);
+	spref.set("offset_2", offset_2); spref.set("oF_2", oF_2);
+	spref.set("f70", f70);   spref.set("m70", m70);
+	spref.set("txT70", txT_70); spref.set("rxT70", rxT_70);
+	spref.set("offset_70", offset_70); spref.set("oF_70", oF_70);
+
 	spref.set("hrd_buttons", hrd_buttons);
 	spref.set("sliders_button", sliders_button);
 }
@@ -997,6 +1084,39 @@ bool status::loadXcvrState(string xcvr)
 		spref.get("command8", defbuffer, command8.c_str(), 499);
 		command8 = defbuffer;
 
+		spref.get("label9", defbuffer,  label9.c_str(), 499);
+		label9 = defbuffer;
+		spref.get("command9", defbuffer, command9.c_str(), 499);
+		command9 = defbuffer;
+		spref.get("label10", defbuffer, label10.c_str(), 499);
+		label10 = defbuffer;
+		spref.get("command10", defbuffer, command10.c_str(), 499);
+		command10 = defbuffer;
+		spref.get("label11", defbuffer, label11.c_str(), 499);
+		label11 = defbuffer;
+		spref.get("command11", defbuffer, command11.c_str(), 499);
+		command11 = defbuffer;
+		spref.get("label12", defbuffer, label12.c_str(), 499);
+		label12 = defbuffer;
+		spref.get("command12", defbuffer, command12.c_str(), 499);
+		command12 = defbuffer;
+		spref.get("label13", defbuffer, label13.c_str(), 499);
+		label13 = defbuffer;
+		spref.get("command13", defbuffer, command13.c_str(), 499);
+		command13 = defbuffer;
+		spref.get("label14", defbuffer, label14.c_str(), 499);
+		label14 = defbuffer;
+		spref.get("command14", defbuffer, command14.c_str(), 499);
+		command14 = defbuffer;
+		spref.get("label15", defbuffer, label15.c_str(), 499);
+		label15 = defbuffer;
+		spref.get("command15", defbuffer, command15.c_str(), 499);
+		command15 = defbuffer;
+		spref.get("label16", defbuffer, label16.c_str(), 499);
+		label16 = defbuffer;
+		spref.get("command16", defbuffer, command16.c_str(), 499);
+		command16 = defbuffer;
+
 		spref.get("fg_red", fg_red, fg_red);
 		spref.get("fg_green", fg_green, fg_green);
 		spref.get("fg_blue", fg_blue, fg_blue);
@@ -1083,6 +1203,43 @@ bool status::loadXcvrState(string xcvr)
 
 		spref.get("rpc_level", rpc_level, rpc_level);
 
+		spref.get("f160", f160, f160); spref.get("m160", m160, m160);
+		spref.get("txT160", txT_160, txT_160); spref.get("rxT160", rxT_160, rxT_160);
+		spref.get("offset_160", offset_160, offset_160); spref.get("oF_160", oF_160, oF_160);
+		spref.get("f80", f80, f80);    spref.get("m80", m80, m80);
+		spref.get("txT80", txT_80, txT_80); spref.get("rxT80", rxT_80, rxT_80);
+		spref.get("offset_80", offset_80, offset_80); spref.get("oF_80", oF_80, oF_80);
+		spref.get("f40", f40, f40);    spref.get("m40", m40, m40);
+		spref.get("txT40", txT_40, txT_40); spref.get("rxT40", rxT_40, rxT_40);
+		spref.get("offset_40", offset_40, offset_40); spref.get("oF_40", oF_40, oF_40);
+		spref.get("f30", f30, f30);    spref.get("m30", m30, m30);
+		spref.get("txT30", txT_30, txT_30); spref.get("rxT30", rxT_30, rxT_30);
+		spref.get("offset_30", offset_30, offset_30); spref.get("oF_30", oF_30, oF_30);
+		spref.get("f20", f20, f20);    spref.get("m20", m20, m20);
+		spref.get("txT20", txT_20, txT_20); spref.get("rxT20", rxT_20, rxT_20);
+		spref.get("offset_20", offset_20, offset_20); spref.get("oF_20", oF_20, oF_20);
+		spref.get("f17", f17, f17);    spref.get("m17", m17, m17);
+		spref.get("txT17", txT_17, txT_17); spref.get("rxT17", rxT_17, rxT_17);
+		spref.get("offset_17", offset_17, offset_17); spref.get("oF_17", oF_17, oF_17);
+		spref.get("f15", f15, f15);    spref.get("m15", m15, m15);
+		spref.get("txT15", txT_15, txT_15); spref.get("rxT15", rxT_15, rxT_15);
+		spref.get("offset_15", offset_15, offset_15); spref.get("oF_15", oF_15, oF_15);
+		spref.get("f12", f12, f12);    spref.get("m12", m12, m12);
+		spref.get("txT12", txT_12, txT_12); spref.get("rxT12", rxT_12, rxT_12);
+		spref.get("offset_12", offset_12, offset_12); spref.get("oF_12", oF_12, oF_12);
+		spref.get("f10", f10, f10);    spref.get("m10", m10, m10);
+		spref.get("txT10", txT_10, txT_10); spref.get("rxT10", rxT_10, rxT_10);
+		spref.get("offset_10", offset_10, offset_10); spref.get("oF_10", oF_10, oF_10);
+		spref.get("f6", f6, f6);       spref.get("m6", m6, m6);
+		spref.get("txT6", txT_6, txT_6); spref.get("rxT6", rxT_6, rxT_6);
+		spref.get("offset_6", offset_6, offset_6); spref.get("oF_6", oF_6, oF_6);
+		spref.get("f2", f2, f2);       spref.get("m2", m2, m2);
+		spref.get("txT2", txT_2, txT_2); spref.get("rxT2", rxT_2, rxT_2);
+		spref.get("offset_2", offset_2, offset_2); spref.get("oF_2", oF_2, oF_2);
+		spref.get("f70", f70, f70);    spref.get("m70", m70, m70);
+		spref.get("txT70", txT_70, txT_70); spref.get("rxT70", rxT_70, rxT_70);
+		spref.get("offset_70", offset_70, offset_70); spref.get("oF_70", oF_70, oF_70);
+
 		if (spref.get("hrd_buttons", i, i)) hrd_buttons = i;
 		spref.get("sliders_button", sliders_button, sliders_button);
 
@@ -1239,6 +1396,15 @@ void status::UI_laststate()
 	btnUser7->label(label7.c_str()); btnUser7->redraw_label();
 	btnUser8->label(label8.c_str()); btnUser8->redraw_label();
 
+	btnUser9->label(label9.c_str()); btnUser9->redraw_label();
+	btnUser10->label(label10.c_str()); btnUser10->redraw_label();
+	btnUser11->label(label11.c_str()); btnUser11->redraw_label();
+	btnUser12->label(label12.c_str()); btnUser12->redraw_label();
+	btnUser13->label(label13.c_str()); btnUser13->redraw_label();
+	btnUser14->label(label14.c_str()); btnUser14->redraw_label();
+	btnUser15->label(label15.c_str()); btnUser15->redraw_label();
+	btnUser16->label(label16.c_str()); btnUser16->redraw_label();
+
 	Fl::scheme(ui_scheme.c_str());
 }
 
@@ -1366,6 +1532,22 @@ string status::info()
 	info << "command 7          : " << command1 << "\n";
 	info << "label 8            : " << label1 << "\n";
 	info << "command 8          : " << command1 << "\n";
+	info << "label 9            : " << label9 << "\n";
+	info << "command 9          : " << command9 << "\n";
+	info << "label 10           : " << label10 << "\n";
+	info << "command 10         : " << command10 << "\n";
+	info << "label 11           : " << label11 << "\n";
+	info << "command 11         : " << command11 << "\n";
+	info << "label 12           : " << label12 << "\n";
+	info << "command 12         : " << command12 << "\n";
+	info << "label 13           : " << label13 << "\n";
+	info << "command 13         : " << command13 << "\n";
+	info << "label 14           : " << label14 << "\n";
+	info << "command 14         : " << command14 << "\n";
+	info << "label 15           : " << label15 << "\n";
+	info << "command 15         : " << command15 << "\n";
+	info << "label 16           : " << label16 << "\n";
+	info << "command 16         : " << command16 << "\n";
 
 	return info.str();
 }
